pub struct CrateOverview {
pub name: String,
pub version: String,
pub date: String,
pub total_downloads: i64,
pub description: Option<String>,
pub documentation: Option<String>,
pub is_cache: bool,
}Fields
name: Stringversion: Stringdate: Stringtotal_downloads: i64description: Option<String>documentation: Option<String>is_cache: boolTrait Implementations
Sourceimpl Clone for CrateOverview
impl Clone for CrateOverview
Sourcefn clone(&self) -> CrateOverview
fn clone(&self) -> CrateOverview
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for CrateOverview
impl ComposeSchema for CrateOverview
Sourceimpl Debug for CrateOverview
impl Debug for CrateOverview
Sourceimpl Default for CrateOverview
impl Default for CrateOverview
Sourcefn default() -> CrateOverview
fn default() -> CrateOverview
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for CrateOverview
impl<'de> Deserialize<'de> for CrateOverview
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl FromQueryResult for CrateOverview
impl FromQueryResult for CrateOverview
Sourcefn from_query_result(row: &QueryResult, pre: &str) -> Result<Self, DbErr>
fn from_query_result(row: &QueryResult, pre: &str) -> Result<Self, DbErr>
Instantiate a Model from a QueryResult Read more
Sourcefn from_query_result_nullable(
row: &QueryResult,
pre: &str,
) -> Result<Self, TryGetError>
fn from_query_result_nullable( row: &QueryResult, pre: &str, ) -> Result<Self, TryGetError>
Transform the error from instantiating a Model from a QueryResult
and converting it to an Option Read more
Sourcefn from_query_result_optional(
res: &QueryResult,
pre: &str,
) -> Result<Option<Self>, DbErr>
fn from_query_result_optional( res: &QueryResult, pre: &str, ) -> Result<Option<Self>, DbErr>
Transform the error from instantiating a Model from a QueryResult
and converting it to an Option
Sourcefn find_by_statement(stmt: Statement) -> SelectorRaw<SelectModel<Self>>
fn find_by_statement(stmt: Statement) -> SelectorRaw<SelectModel<Self>>
Sourceimpl PartialEq for CrateOverview
impl PartialEq for CrateOverview
Sourceimpl Serialize for CrateOverview
impl Serialize for CrateOverview
Sourceimpl ToSchema for CrateOverview
impl ToSchema for CrateOverview
impl Eq for CrateOverview
impl StructuralPartialEq for CrateOverview